@@ -13,9 +13,6 @@
 #define COMIC_H
 
 #include <QDate>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QNetworkConfigurationManager>
-#endif
 #include <QUrl>
 
 #include <Plasma/Applet>
@@ -50,7 +47,6 @@ class ComicApplet : public Plasma::Applet
     Q_PROPERTY(bool showActualSize READ showActualSize WRITE setShowActualSize NOTIFY showActualSizeChanged)
     Q_PROPERTY(QStringList tabIdentifiers READ tabIdentifiers WRITE setTabIdentifiers NOTIFY tabIdentifiersChanged)
     Q_PROPERTY(int checkNewComicStripsInterval READ checkNewComicStripsInterval WRITE setCheckNewComicStripsInterval NOTIFY checkNewComicStripsIntervalChanged)
-    Q_PROPERTY(int providerUpdateInterval READ providerUpdateInterval WRITE setProviderUpdateInterval NOTIFY providerUpdateIntervalChanged)
     Q_PROPERTY(int maxComicLimit READ maxComicLimit WRITE setMaxComicLimit NOTIFY maxComicLimitChanged)
 
 public:
@@ -95,9 +91,6 @@ public:
     int checkNewComicStripsInterval() const;
     void setCheckNewComicStripsInterval(int interval);
 
-    int providerUpdateInterval() const;
-    void setProviderUpdateInterval(int interval);
-
     void setMaxComicLimit(int limit);
     int maxComicLimit() const;
     // End for QML
@@ -117,7 +110,6 @@ Q_SIGNALS:
     void showActualSizeChanged();
     void tabIdentifiersChanged();
     void checkNewComicStripsIntervalChanged();
-    void providerUpdateIntervalChanged();
     void maxComicLimitChanged();
 
 private Q_SLOTS:
@@ -170,12 +162,6 @@ private:
 
 private:
     ComicModel *mModel;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_DEPRECATED
-    QNetworkConfigurationManager m_networkConfigurationManager;
-    QT_WARNING_POP
-#endif
     QString mPreviousFailedIdentifier;
     QSortFilterProxyModel *mProxy;
     ActiveComicModel *mActiveComicModel;
